==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="33"/>
        <source>Show playlist manipulation commands</source>
        <translation>הצג פקודות תפעול רשימת נגינה</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="34"/>
        <source>List all available playlists</source>
        <translation>הצג את כל רשימות הנגינה הזמינות</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="35"/>
        <source>Show playlist content</source>
        <translation>הצג תוכן רשימת נגינה</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="36"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation>נגן את רצועה &lt;track&gt; מתוך רשימת נגינה &lt;id&gt;</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="37"/>
        <source>Clear playlist</source>
        <translation>טהר רשימת נגינה</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="38"/>
        <source>Toggle playlist repeat</source>
        <translation>אפשר/נטרל חזרת רשימת נגינת</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="39"/>
        <source>Toggle playlist shuffle</source>
        <translation>אפשר/נטרל אקראיות רשימת נגינת</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="40"/>
        <source>Show playlist options</source>
        <translation>הצג אפשרויות רשימת נגינה</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="104"/>
        <location filename="../playlistoption.cpp" line="126"/>
        <location filename="../playlistoption.cpp" line="143"/>
        <source>Invalid playlist ID</source>
        <translation>מזהה רשימת נגינה לא תקף</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="120"/>
        <source>Invalid number of arguments</source>
        <translation>מספר ארגומנטים לא תקין</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="130"/>
        <source>Invalid track ID</source>
        <translation>מזהה רצועה לא תקף</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/CommandLineOptions/PlayListOption/translations/playlist_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>PlayListOption</name>
    <message>
        <location filename="../playlistoption.cpp" line="33"/>
        <source>Show playlist manipulation commands</source>
        <translation>הצג פקודות תפעול רשימת נגינה</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="34"/>
        <source>List all available playlists</source>
        <translation>הצג את כל רשימות הנגינה הזמינות</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="35"/>
        <source>Show playlist content</source>
        <translation>הצג תוכן רשימת נגינה</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="36"/>
        <source>Play track &lt;track&gt; in playlist &lt;id&gt;</source>
        <translation>נגן את רצועה &lt;track&gt; מתוך רשימת נגינה &lt;id&gt;</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="37"/>
        <source>Clear playlist</source>
        <translation>טהר רשימת נגינה</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="38"/>
        <source>Activate next playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="39"/>
        <source>Activate previous playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="40"/>
        <source>Toggle playlist repeat</source>
        <translation>אפשר/נטרל חזרת רשימת נגינת</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="41"/>
        <source>Toggle playlist shuffle</source>
        <translation>אפשר/נטרל אקראיות רשימת נגינת</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="42"/>
        <source>Show playlist options</source>
        <translation>הצג אפשרויות רשימת נגינה</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="110"/>
        <location filename="../playlistoption.cpp" line="132"/>
        <location filename="../playlistoption.cpp" line="171"/>
        <source>Invalid playlist ID</source>
        <translation>מזהה רשימת נגינה לא תקף</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="126"/>
        <source>Invalid number of arguments</source>
        <translation>מספר ארגומנטים לא תקין</translation>
    </message>
    <message>
        <location filename="../playlistoption.cpp" line="136"/>
        <source>Invalid track ID</source>
        <translation>מזהה רצועה לא תקף</translation>
    </message>
</context>
</TS>
